==> pipewire-docs-1%3A0.3.32-2-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/param_2type-info_8h.js <==
var param_2type_info_8h =
[
    [ "SPA_TYPE_INFO_Format", "group__spa__param.html#ga9c4f60adda447be6743c1cb662e4f915", null ],
    [ "SPA_TYPE_INFO_FORMAT_AUDIO_BASE", "group__spa__param.html#ga88d8a6b1829732d2366f668c1434a6f1", null ],
    [ "SPA_TYPE_INFO_FORMAT_BASE", "group__spa__param.html#gaef7d2b159ae3dff206495de5e4658c14", null ],
    [ "SPA_TYPE_INFO_FORMAT_VIDEO_BASE", "group__spa__param.html#ga1b5f32624486c9bbd41221636892f2c6", null ],
    [ "SPA_TYPE_INFO_FORMAT_VIDEO_H264", "group__spa__param.html#ga8a7bfb7c1573298e98d3c41320477036", null ],
    [ "SPA_TYPE_INFO_FORMAT_VIDEO_H264_BASE", "group__spa__param.html#gac4bc534452a26f8b8ce03f18211e0a60", null ],
    [ "SPA_TYPE_INFO_FormatAudio", "group__spa__param.html#gadf20a282139c86a669212c8d36262ad6", null ],
    [ "SPA_TYPE_INFO_FormatVideo", "group__spa__param.html#gac12961618e153491d8be96b80b74dafe", null ],
    [ "SPA_TYPE_INFO_MEDIA_SUBTYPE_BASE", "group__spa__param.html#gaf9b396d2a32d0c662679157b30f9487a", null ],
    [ "SPA_TYPE_INFO_MEDIA_TYPE_BASE", "group__spa__param.html#ga945da9cf54f55efd0ff9e84b2ae06818", null ],
    [ "SPA_TYPE_INFO_MediaSubtype", "group__spa__param.html#ga49f07c95d71f747d84998d28c475b999", null ],
    [ "SPA_TYPE_INFO_MediaType", "group__spa__param.html#ga56f3307a1c6f7369c85052fd66a57b6e", null ],
    [ "SPA_TYPE_INFO_Param", "group__spa__param.html#ga893e9f277741b9c90b05607b9a1faba1", null ],
    [ "SPA_TYPE_INFO_PARAM_AVAILABILITY_BASE", "group__spa__param.html#ga7fcdcde21cef167e3f88b387c3288f4b", null ],
    [ "SPA_TYPE_INFO_PARAM_BASE", "group__spa__param.html#ga4f5f864f3f87180c8dc271424b65a310", null ],
    [ "SPA_TYPE_INFO_PARAM_BLOCK_INFO_BASE", "group__spa__param.html#gabc60f80c708ffce3fa6759cc97a94bca", null ],
    [ "SPA_TYPE_INFO_PARAM_BlockInfo", "group__spa__param.html#ga4cb83f6140abbc445c49e1bbb82f58bf", null ],
    [ "SPA_TYPE_INFO_PARAM_Buffers", "group__spa__param.html#ga8d782c776ae479f844c5358650f0598e", null ],
    [ "SPA_TYPE_INFO_PARAM_BUFFERS_BASE", "group__spa__param.html#gaf0e1ffbdb3b160dbab529216e9311a77", null ],
    [ "SPA_TYPE_INFO_PARAM_ID_BASE", "group__spa__param.html#ga6a2f33dd7421c54c7f46f377a58fd22b", null ],
    [ "SPA_TYPE_INFO_PARAM_IO", "group__spa__param.html#ga3c3d68289ff05f7d3e60648cd5c6ae0d", null ],
    [ "SPA_TYPE_INFO_PARAM_IO_BASE", "group__spa__param.html#gae6bae1b6f8d0477c328591c12f4cb5d0", null ],
    [ "SPA_TYPE_INFO_PARAM_Latency", "group__spa__param.html#ga90558703b75bd503aab2fe68032bcccd", null ],
    [ "SPA_TYPE_INFO_PARAM_LATENCY_BASE", "group__spa__param.html#gade2004253a80b3f76b870bbaaa433e38", null ],
    [ "SPA_TYPE_INFO_PARAM_Meta", "group__spa__param.html#ga1fa13d1ffee676f6fac4a44b2a5e755d", null ],
    [ "SPA_TYPE_INFO_PARAM_META_BASE", "group__spa__param.html#ga8e6f90709bb0d31d798cbd0dfa19b872", null ],
    [ "SPA_TYPE_INFO_PARAM_PORT_CONFIG_BASE", "group__spa__param.html#ga7839ce7f7e5ac788f3415a12604fb2de", null ],
    [ "SPA_TYPE_INFO_PARAM_PORT_CONFIG_MODE_BASE", "group__spa__param.html#ga5470509ff68cb4e90bf9049c8e16c0d4", null ],
    [ "SPA_TYPE_INFO_PARAM_PortConfig", "group__spa__param.html#gaff4d75d2c42fdee281818ead9cce1324", null ],
    [ "SPA_TYPE_INFO_PARAM_PROCESS_LATENCY_BASE", "group__spa__param.html#ga335982acb47c6a2456e6133cd8caf64d", null ],
    [ "SPA_TYPE_INFO_PARAM_ProcessLatency", "group__spa__param.html#gab0c0f9c822151f4f65125d05e6d80c63", null ],
    [ "SPA_TYPE_INFO_PARAM_Profile", "group__spa__param.html#ga33238198e192056d4aba1b75fb7c5828", null ],
    [ "SPA_TYPE_INFO_PARAM_PROFILE_BASE", "group__spa__param.html#ga7f188485cf47ffb05c8f6be407448f2c", null ],
    [ "SPA_TYPE_INFO_PARAM_Route", "group__spa__param.html#gaccfc57933a1f98793dc5278697f32033", null ],
    [ "SPA_TYPE_INFO_PARAM_ROUTE_BASE", "group__spa__param.html#gafab5d6ef4d28f6744624bb768fb61eb1", null ],
    [ "SPA_TYPE_INFO_ParamAvailability", "group__spa__param.html#ga529f78365e444b02e98419365623364e", null ],
    [ "SPA_TYPE_INFO_ParamId", "group__spa__param.html#ga04d3e6dfcfd91117b65d05f2d975de2e", null ],
    [ "SPA_TYPE_INFO_ParamPortConfigMode", "group__spa__param.html#gae3beebbcde434be3e21cbdb46edb92fc", null ],
    [ "SPA_TYPE_INFO_Profiler", "group__spa__param.html#gaa15a8b3a530dd31feaee63ddaff237a7", null ],
    [ "SPA_TYPE_INFO_PROFILER_BASE", "group__spa__param.html#ga81a529eb5bc8269bee185459cf72b942", null ],
    [ "SPA_TYPE_INFO_PROP_INFO_BASE", "group__spa__param.html#ga43c56d263c416f6f2a6f22e45d5d02f5", null ],
    [ "SPA_TYPE_INFO_PropInfo", "group__spa__param.html#ga7855eff886ceadadd9cd60514351ff87", null ],
    [ "SPA_TYPE_INFO_Props", "group__spa__param.html#gad3d15175ea1dfed4f9d89d6ec0ee86a1", null ],
    [ "SPA_TYPE_INFO_PROPS_BASE", "group__spa__param.html#gad9b5886f7112d70a26aa55d2c79e38bf", null ],
    [ "spa_type_format", "group__spa__param.html#ga563b4a1a0c6673399fc8efba3205ccb5", null ],
    [ "spa_type_media_subtype", "group__spa__param.html#ga06de5cc894f85c3b50d27de8b673cdf1", null ],
    [ "spa_type_media_type", "group__spa__param.html#gad416a2730dbb9c18522bef04db3a9daf", null ],
    [ "spa_type_param", "group__spa__param.html#gac4e41d33f933cc70296e93f123d689d3", null ],
    [ "spa_type_param_availability", "group__spa__param.html#ga20f320fbfbbf4ac36f0a3fcdd94effeb", null ],
    [ "spa_type_param_buffers", "group__spa__param.html#ga6278ad3cccbd9b9b0146b2884c2b30b0", null ],
    [ "spa_type_param_io", "group__spa__param.html#ga24da9c08ff79945bed1ddc0f8ea4657f", null ],
    [ "spa_type_param_latency", "group__spa__param.html#ga33f0a35e92a0ca6a02de1df1e2ac6aa7", null ],
    [ "spa_type_param_meta", "group__spa__param.html#ga5a68c1a81633e02096ddc0fe1dd22eb6", null ],
    [ "spa_type_param_port_config", "group__spa__param.html#ga25f8779144464681be600ac9159bd136", null ],
    [ "spa_type_param_port_config_mode", "group__spa__param.html#ga082a4ac95118f711b0e433c956a3d9b4", null ],
    [ "spa_type_param_process_latency", "group__spa__param.html#gaac78a07f4368726d8a5dbd79460cdef1", null ],
    [ "spa_type_param_profile", "group__spa__param.html#ga0413f766ae07ed11f9beae6d7c8c5994", null ],
    [ "spa_type_param_route", "group__spa__param.html#gaedfa489b4bf916ad7b34794a1cf195a3", null ],
    [ "spa_type_profiler", "group__spa__param.html#gad88ab97ac4ca1b22daa4630ff8cdfa4c", null ],
    [ "spa_type_prop_channel_map", "group__spa__param.html#ga09f7762c87d701e203736dc9bd9d2482", null ],
    [ "spa_type_prop_float_array", "group__spa__param.html#ga5f7d6cec518134141d66d88cae95b4c6", null ],
    [ "spa_type_prop_info", "group__spa__param.html#ga16dbda7d0628b8d175072a57204690f4", null ],
    [ "spa_type_props", "group__spa__param.html#ga623ced681d45e0c804859e5bdda75fd7", null ]
];

==> pipewire-docs-1%3A0.3.34-1-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/param_2type-info_8h.js <==
var param_2type_info_8h =
[
    [ "SPA_TYPE_INFO_Format", "group__spa__param.html#ga9c4f60adda447be6743c1cb662e4f915", null ],
    [ "SPA_TYPE_INFO_FORMAT_AUDIO_BASE", "group__spa__param.html#ga88d8a6b1829732d2366f668c1434a6f1", null ],
    [ "SPA_TYPE_INFO_FORMAT_BASE", "group__spa__param.html#gaef7d2b159ae3dff206495de5e4658c14", null ],
    [ "SPA_TYPE_INFO_FORMAT_VIDEO_BASE", "group__spa__param.html#ga1b5f32624486c9bbd41221636892f2c6", null ],
    [ "SPA_TYPE_INFO_FORMAT_VIDEO_H264", "group__spa__param.html#ga8a7bfb7c1573298e98d3c41320477036", null ],
    [ "SPA_TYPE_INFO_FORMAT_VIDEO_H264_BASE", "group__spa__param.html#gac4bc534452a26f8b8ce03f18211e0a60", null ],
    [ "SPA_TYPE_INFO_FormatAudio", "group__spa__param.html#gadf20a282139c86a669212c8d36262ad6", null ],
    [ "SPA_TYPE_INFO_FormatVideo", "group__spa__param.html#gac12961618e153491d8be96b80b74dafe", null ],
    [ "SPA_TYPE_INFO_MEDIA_SUBTYPE_BASE", "group__spa__param.html#gaf9b396d2a32d0c662679157b30f9487a", null ],
    [ "SPA_TYPE_INFO_MEDIA_TYPE_BASE", "group__spa__param.html#ga945da9cf54f55efd0ff9e84b2ae06818", null ],
    [ "SPA_TYPE_INFO_MediaSubtype", "group__spa__param.html#ga49f07c95d71f747d84998d28c475b999", null ],
    [ "SPA_TYPE_INFO_MediaType", "group__spa__param.html#ga56f3307a1c6f7369c85052fd66a57b6e", null ],
    [ "SPA_TYPE_INFO_Param", "group__spa__param.html#ga893e9f277741b9c90b05607b9a1faba1", null ],
    [ "SPA_TYPE_INFO_PARAM_AVAILABILITY_BASE", "group__spa__param.html#ga7fcdcde21cef167e3f88b387c3288f4b", null ],
    [ "SPA_TYPE_INFO_PARAM_BASE", "group__spa__param.html#ga4f5f864f3f87180c8dc271424b65a310", null ],
    [ "SPA_TYPE_INFO_PARAM_BLOCK_INFO_BASE", "group__spa__param.html#gabc60f80c708ffce3fa6759cc97a94bca", null ],
    [ "SPA_TYPE_INFO_PARAM_BlockInfo", "group__spa__param.html#ga4cb83f6140abbc445c49e1bbb82f58bf", null ],
    [ "SPA_TYPE_INFO_PARAM_Buffers", "group__spa__param.html#ga8d782c776ae479f844c5358650f0598e", null ],
    [ "SPA_TYPE_INFO_PARAM_BUFFERS_BASE", "group__spa__param.html#gaf0e1ffbdb3b160dbab529216e9311a77", null ],
    [ "SPA_TYPE_INFO_PARAM_ID_BASE", "group__spa__param.html#ga6a2f33dd7421c54c7f46f377a58fd22b", null ],
    [ "SPA_TYPE_INFO_PARAM_IO", "group__spa__param.html#ga3c3d68289ff05f7d3e60648cd5c6ae0d", null ],
    [ "SPA_TYPE_INFO_PARAM_IO_BASE", "group__spa__param.html#gae6bae1b6f8d0477c328591c12f4cb5d0", null ],
    [ "SPA_TYPE_INFO_PARAM_Latency", "group__spa__param.html#ga90558703b75bd503aab2fe68032bcccd", null ],
    [ "SPA_TYPE_INFO_PARAM_LATENCY_BASE", "group__spa__param.html#gade2004253a80b3f76b870bbaaa433e38", null ],
    [ "SPA_TYPE_INFO_PARAM_Meta", "group__spa__param.html#ga1fa13d1ffee676f6fac4a44b2a5e755d", null ],
    [ "SPA_TYPE_INFO_PARAM_META_BASE", "group__spa__param.html#ga8e6f90709bb0d31d798cbd0dfa19b872", null ],
    [ "SPA_TYPE_INFO_PARAM_PORT_CONFIG_BASE", "group__spa__param.html#ga7839ce7f7e5ac788f3415a12604fb2de", null ],
    [ "SPA_TYPE_INFO_PARAM_PORT_CONFIG_MODE_BASE", "group__spa__param.html#ga5470509ff68cb4e90bf9049c8e16c0d4", null ],
    [ "SPA_TYPE_INFO_PARAM_PortConfig", "group__spa__param.html#gaff4d75d2c42fdee281818ead9cce1324", null ],
    [ "SPA_TYPE_INFO_PARAM_PROCESS_LATENCY_BASE", "group__spa__param.html#ga335982acb47c6a2456e6133cd8caf64d", null ],
    [ "SPA_TYPE_INFO_PARAM_ProcessLatency", "group__spa__param.html#gab0c0f9c822151f4f65125d05e6d80c63", null ],
    [ "SPA_TYPE_INFO_PARAM_Profile", "group__spa__param.html#ga33238198e192056d4aba1b75fb7c5828", null ],
    [ "SPA_TYPE_INFO_PARAM_PROFILE_BASE", "group__spa__param.html#ga7f188485cf47ffb05c8f6be407448f2c", null ],
    [ "SPA_TYPE_INFO_PARAM_Route", "group__spa__param.html#gaccfc57933a1f98793dc5278697f32033", null ],
    [ "SPA_TYPE_INFO_PARAM_ROUTE_BASE", "group__spa__param.html#gafab5d6ef4d28f6744624bb768fb61eb1", null ],
    [ "SPA_TYPE_INFO_ParamAvailability", "group__spa__param.html#ga529f78365e444b02e98419365623364e", null ],
    [ "SPA_TYPE_INFO_ParamId", "group__spa__param.html#ga04d3e6dfcfd91117b65d05f2d975de2e", null ],
    [ "SPA_TYPE_INFO_ParamPortConfigMode", "group__spa__param.html#gae3beebbcde434be3e21cbdb46edb92fc", null ],
    [ "SPA_TYPE_INFO_Profiler", "group__spa__param.html#gaa15a8b3a530dd31feaee63ddaff237a7", null ],
    [ "SPA_TYPE_INFO_PROFILER_BASE", "group__spa__param.html#ga81a529eb5bc8269bee185459cf72b942", null ],
    [ "SPA_TYPE_INFO_PROP_INFO_BASE", "group__spa__param.html#ga43c56d263c416f6f2a6f22e45d5d02f5", null ],
    [ "SPA_TYPE_INFO_PropInfo", "group__spa__param.html#ga7855eff886ceadadd9cd60514351ff87", null ],
    [ "SPA_TYPE_INFO_Props", "group__spa__param.html#gad3d15175ea1dfed4f9d89d6ec0ee86a1", null ],
    [ "SPA_TYPE_INFO_PROPS_BASE", "group__spa__param.html#gad9b5886f7112d70a26aa55d2c79e38bf", null ],
    [ "spa_type_format", "group__spa__param.html#ga563b4a1a0c6673399fc8efba3205ccb5", null ],
    [ "spa_type_media_subtype", "group__spa__param.html#ga06de5cc894f85c3b50d27de8b673cdf1", null ],
    [ "spa_type_media_type", "group__spa__param.html#gad416a2730dbb9c18522bef04db3a9daf", null ],
    [ "spa_type_param", "group__spa__param.html#gac4e41d33f933cc70296e93f123d689d3", null ],
    [ "spa_type_param_availability", "group__spa__param.html#ga20f320fbfbbf4ac36f0a3fcdd94effeb", null ],
    [ "spa_type_param_buffers", "group__spa__param.html#ga6278ad3cccbd9b9b0146b2884c2b30b0", null ],
    [ "spa_type_param_io", "group__spa__param.html#ga24da9c08ff79945bed1ddc0f8ea4657f", null ],
    [ "spa_type_param_latency", "group__spa__param.html#ga33f0a35e92a0ca6a02de1df1e2ac6aa7", null ],
    [ "spa_type_param_meta", "group__spa__param.html#ga5a68c1a81633e02096ddc0fe1dd22eb6", null ],
    [ "spa_type_param_port_config", "group__spa__param.html#ga25f8779144464681be600ac9159bd136", null ],
    [ "spa_type_param_port_config_mode", "group__spa__param.html#ga082a4ac95118f711b0e433c956a3d9b4", null ],
    [ "spa_type_param_process_latency", "group__spa__param.html#gaac78a07f4368726d8a5dbd79460cdef1", null ],
    [ "spa_type_param_profile", "group__spa__param.html#ga0413f766ae07ed11f9beae6d7c8c5994", null ],
    [ "spa_type_param_route", "group__spa__param.html#gaedfa489b4bf916ad7b34794a1cf195a3", null ],
    [ "spa_type_profiler", "group__spa__param.html#gad88ab97ac4ca1b22daa4630ff8cdfa4c", null ],
    [ "spa_type_prop_channel_map", "group__spa__param.html#ga09f7762c87d701e203736dc9bd9d2482", null ],
    [ "spa_type_prop_float_array", "group__spa__param.html#ga5f7d6cec518134141d66d88cae95b4c6", null ],
    [ "spa_type_prop_iec958_codec", "group__spa__param.html#gaf5ce5d65a230b052b94e9768399d9763", null ],
    [ "spa_type_prop_info", "group__spa__param.html#ga16dbda7d0628b8d175072a57204690f4", null ],
    [ "spa_type_props", "group__spa__param.html#ga623ced681d45e0c804859e5bdda75fd7", null ]
];
